@@ -32,10 +32,10 @@ def get_less_distant_item(to_compare, options):
 
     for option in options:
         distance = jellyfish.levenshtein_distance(to_compare, option)
-
-        if not last_distance:
+        
+        if last_distance == None:
             last_distance = distance
-        elif last_distance < distance:
+        elif distance > last_distance:
             continue
         
         last_distance = distance
